SystemOrganization addCategory: #'Minecraft-Pi-Base'!

Object subclass: #Minecraft
	instanceVariableNames: 'connection'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Minecraft-Pi-Base'!

!Minecraft commentStamp: 'bf 2/24/2013 23:30' prior: 0!
Squeak bindings for "Minecraft: Pi Edition"
Author: Bert Freudenberg <bert@freudenbergs.de>
See http://pi.minecraft.net/

This class allows to communicate with a Minecraft game running on a Raspberry Pi. Squeak can either run on the same machine or remotely.

Instance Variables
	connection:		<MinecraftConnection>

Example
	| mc |
	mc := Minecraft connectTo: 'raspberrypi'.
	mc chatPost: 'Hi from Squeak!!'.
	Transcript show: 'Player pos: '; show: mc playerPos; cr.
	mc close.
!

!Minecraft class methodsFor: 'instance creation' stamp: 'bf 2/24/2013 21:18'!
connect
	^self connectTo: 'localhost'! !

!Minecraft class methodsFor: 'instance creation' stamp: 'bf 2/24/2013 21:19'!
connectTo: hostName
	^self connectTo: hostName port: 4711
! !

!Minecraft class methodsFor: 'instance creation' stamp: 'bf 2/24/2013 21:19'!
connectTo: hostName port: portNumber
	^self new connection: (MinecraftConnection host: hostName port: portNumber)
! !

!Minecraft methodsFor: 'blocks' stamp: 'bf 2/25/2013 00:30'!
blockAndDataAt: vector3
	"return block id and data"
	^self toNumbers: (connection send: 'world.getBlockWithData' args: vector3 floor; receive)
! !

!Minecraft methodsFor: 'blocks' stamp: 'bf 2/25/2013 00:54'!
blockAt: vector3
	"return block id"
	^(connection send: 'world.getBlock' args: vector3 floor; receive) asNumber
! !

!Minecraft methodsFor: 'blocks' stamp: 'bf 2/25/2013 00:22'!
blockAt: vector3 put: blockIdOrIdAndData
	connection send: 'world.setBlock' args: vector3 floor, (self toArray: blockIdOrIdAndData).
! !

!Minecraft methodsFor: 'blocks' stamp: 'bf 2/25/2013 00:23'!
blocksFrom: from3 to: to3 put: blockIdOrIdAndData
	"Fill cube with given block id (or block id and data)"
	connection send: 'world.setBlocks' args: from3 floor, to3 floor, (self toArray: blockIdOrIdAndData).
! !

!Minecraft methodsFor: 'camera' stamp: 'bf 2/24/2013 22:16'!
cameraModeFixed
	^connection send: 'camera.mode.setFixed'! !

!Minecraft methodsFor: 'camera' stamp: 'bf 2/24/2013 22:17'!
cameraModeFollow
	^connection send: 'camera.mode.setFollow'! !

!Minecraft methodsFor: 'camera' stamp: 'bf 2/24/2013 22:16'!
cameraModeNormal
	^connection send: 'camera.mode.setNormal'! !

!Minecraft methodsFor: 'camera' stamp: 'bf 2/24/2013 22:02'!
cameraPos: vector3
	^connection send: 'camera.setPos' args: vector3	! !

!Minecraft methodsFor: 'chat' stamp: 'bf 2/24/2013 21:55'!
chatPost: aString
	connection send: 'chat.post' args: aString
! !

!Minecraft methodsFor: 'checkpoints' stamp: 'bf 2/24/2013 23:56'!
checkpointRestore
	connection send: 'world.checkpoint.restore'.

! !

!Minecraft methodsFor: 'checkpoints' stamp: 'bf 2/24/2013 23:56'!
checkpointSave
	connection send: 'world.checkpoint.save'.

! !

!Minecraft methodsFor: 'events' stamp: 'bf 2/25/2013 00:01'!
clearEvents
	connection send: 'events.clear'.
! !

!Minecraft methodsFor: 'initialize-release' stamp: 'bf 2/24/2013 22:06'!
close
	connection close
! !

!Minecraft methodsFor: 'initialize-release' stamp: 'bf 2/24/2013 21:17'!
connection: aConnection
	connection := aConnection.
! !

!Minecraft methodsFor: 'blocks' stamp: 'bf 2/25/2013 00:53'!
heightAt: vector2
	"return world height at xz-pos"
	^(connection send: 'world.getHeight' args: vector2 floor; receive) asNumber
! !

!Minecraft methodsFor: 'entities' stamp: 'bf 2/24/2013 22:33'!
playerIds
	"Get entity ids of all players"
	^self toNumbers: (connection send: 'world.getPlayerIds'; receive)
	! !

!Minecraft methodsFor: 'player' stamp: 'bf 2/24/2013 22:22'!
playerPos
	^self toNumbers: (connection send: 'player.getPos'; receive)
	! !

!Minecraft methodsFor: 'player' stamp: 'bf 2/24/2013 22:02'!
playerPos: vector3
	^connection send: 'player.setPos' args: vector3	! !

!Minecraft methodsFor: 'settings' stamp: 'bf 2/24/2013 23:54'!
playerSetting: key value: value
	"Keys:
		'autojump'
	"
	connection send: 'player.setting' args: {key. value}! !

!Minecraft methodsFor: 'player' stamp: 'bf 2/24/2013 22:22'!
playerTile
	^self toNumbers: (connection send: 'player.getTile'; receive)
	! !

!Minecraft methodsFor: 'player' stamp: 'bf 2/24/2013 22:02'!
playerTile: vector3
	^connection send: 'player.setTile' args: vector3	! !

!Minecraft methodsFor: 'events' stamp: 'bf 2/25/2013 00:32'!
pollBlockHits
	"triggered by sword right-click"
	^((connection send: 'events.block.hits'; receive)
		findTokens: '|')
			collect: [:event | self toNumbers: event]! !

!Minecraft methodsFor: 'entities' stamp: 'bf 2/24/2013 22:23'!
posOf: entityId
	^self toNumbers: (connection send: 'entity.getPos' args: entityId; receive)
	! !

!Minecraft methodsFor: 'entities' stamp: 'bf 2/24/2013 22:30'!
setPosOf: entityId to: vector3
	connection send: 'entity.setPos' args: {entityId}, vector3.

	! !

!Minecraft methodsFor: 'entities' stamp: 'bf 2/24/2013 22:30'!
setTileOf: entityId to: vector3
	connection send: 'entity.setTile' args: {entityId}, vector3.

	! !

!Minecraft methodsFor: 'entities' stamp: 'bf 2/24/2013 22:24'!
tileOf: entityId
	^self toNumbers: (connection send: 'entity.getTile' args: entityId; receive)
	! !

!Minecraft methodsFor: 'private' stamp: 'bf 2/24/2013 22:58'!
toArray: numberOrArray
	^numberOrArray isNumber
		ifTrue: [{numberOrArray}]
		ifFalse: [numberOrArray].! !

!Minecraft methodsFor: 'private' stamp: 'bf 3/10/2013 13:32'!
toNumbers: aString
	^Array streamContents: [:out | | in |
		in := aString readStream.
		[in atEnd] whileFalse: [
			out nextPut: (in upToAnyOf: ',|') asNumber]]
! !

!Minecraft methodsFor: 'settings' stamp: 'bf 2/24/2013 23:52'!
worldSetting: key value: value
	"Keys:
		'nametags_visible'
		'world_immutable'
	"
	connection send: 'world.setting' args: {key. value}! !

Object subclass: #MinecraftConnection
	instanceVariableNames: 'stream lastSent'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Minecraft-Pi-Base'!

!MinecraftConnection commentStamp: 'bf 2/24/2013 23:30' prior: 0!
An MinecraftConnection is used to send commands to and receive results from a Minecraft game.

Instance Variables
	stream:		<SocketStream>

Example
	| conn pos |
	conn := MinecraftConnection host: 'raspberrypi' port: 4711.
	conn send: 'chat.post' args: 'Hi from Squeak!!'.
	pos := conn send: 'player.getPos'; receive.
	Transcript show: 'Player pos: '; show: pos; cr.
	conn close.
!

!MinecraftConnection class methodsFor: 'instance creation' stamp: 'bf 2/24/2013 20:44'!
host: hostName port: portNumber
	| stream |
	stream := SocketStream openConnectionToHostNamed: hostName port: portNumber.
	stream timeout: 5.
	^self new stream: stream! !

!MinecraftConnection methodsFor: 'initialize-release' stamp: 'bf 2/24/2013 18:12'!
close
	stream close.
! !

!MinecraftConnection methodsFor: 'private' stamp: 'bf 2/24/2013 20:39'!
drain
	"Drain all incoming data"
	[stream isDataAvailable]
		whileTrue: [ | data |
			data := stream nextAvailable.
			Transcript show: 'Drained: ', data; cr.
			Transcript show: 'Last message: ', lastSent].
! !

!MinecraftConnection methodsFor: 'private' stamp: 'bf 2/24/2013 23:43'!
print: argument on: aStream
	"Format arguments: comma-separated collections"
	| first |
	argument isString ifTrue: [^aStream nextPutAll: argument].
	argument isNumber ifTrue: [^aStream print: argument].
	argument == false ifTrue: [^aStream nextPut: $0].
	argument == true ifTrue: [^aStream nextPut: $1].
	"accept anything that implements #do:"
	first := true.
	argument do: [:each |
		first ifFalse: [aStream nextPut: $,].
		self print: each on: aStream.
		first := false].
! !

!MinecraftConnection methodsFor: 'data' stamp: 'bf 2/24/2013 23:29'!
receive
	"receive a line"
	| line |
	line := stream flush; nextLineLf.
	"Transcript show: 'Received ', line; cr."
	line = 'Fail'
		ifTrue: [^self error: lastSent, ' failed'].
	^line! !

!MinecraftConnection methodsFor: 'data' stamp: 'bf 2/24/2013 21:47'!
send: function
	^self send: function args: #()! !

!MinecraftConnection methodsFor: 'data' stamp: 'bf 2/24/2013 23:29'!
send: function args: arguments
	"Send 'function(arg1,arg2,...,argN)' and a linefeed"
	| line |
	self drain.
	line := String streamContents: [:s |
		s nextPutAll: function.
		s nextPut: $(.
		self print: arguments on: s.
		s nextPut: $).
		s lf].
	stream nextPutAll: line.
	stream flush.
	lastSent := line allButLast.
	"Transcript show: 'Sent ', line allButLast; cr."
! !

!MinecraftConnection methodsFor: 'initialize-release' stamp: 'bf 2/24/2013 16:10'!
stream: aSocketStream
	stream := aSocketStream.
! !

SharedPool subclass: #MinecraftConstants
	instanceVariableNames: ''
	classVariableNames: 'ActivatorRail Air Anvil Apple Arrow AwkwardPotion BakedPotato BatSpawnEgg Beacon Bed BedBlock Bedrock BirchLeaves BirchSapling BirchWood BirchWoodSlab BirchWoodSlabDouble BirchWoodenPlank BirchWoodenStairs BlackWool BlazePowder BlazeRod BlazeSpawnEgg BlockofDiamond BlockofEmerald BlockofGold BlockofIron BlockofRedstone BlueWool Boat Bone BoneMeal Book BookandQuill Bookcase BottleofEnchanting Bow Bowl Bread BrewingStand BrewingStandBlock Brick BrickSlab BrickSlabDouble BrickStairs BrownMushroom BrownMushroomBlock BrownWool Bucket Cactus CactusGreenDye Cake CakeBlock Carrot CarrotCrop CarrotonaStick Cauldron CauldronBlock CaveSpiderSpawnEgg ChainmailBoots ChainmailChestplate ChainmailHelmet ChainmailLeggings Charcoal Chest ChickenSpawnEgg ChiseledQuartzBlock ChiseledSandstone ChiseledStoneBrick Clay ClayBlock ClayBrick Coal CoalOre Cobblestone CobblestoneSlab CobblestoneSlabDouble CobblestoneStairs CobblestoneWall CocaBean CocaPlant CommandBlock Compass CookedChicken CookedFish CookedPorkchop Cookie CowSpawnEgg CrackedStoneBricks CreeperHead CreeperHeadBlock CreeperSpawnEgg CyanDye CyanWool Dandelion DandelionYellowDye DaylightSensor DeadShrub DetectorRail DiamondAxe DiamondBoots DiamondChestplate DiamondGem DiamondHelmet DiamondHoe DiamondLeggings DiamondOre DiamondPickaxe DiamondShovel DiamondSword Dirt Dispenser DragonEgg Dropper Egg Emerald EmeraldOre EmptyMap EnchantedBook EnchantedGoldenApple EnchantmentTable EndPortal EndPortalFrame EndStone EnderChest EnderPearl EndermenSpawnEgg EyeofEnder Farmland Feather Fence FenceGate FermentedSpiderEye Fire FireCharge FireResistancePotion300 FireResistancePotion800 FireResistanceSplash215 FireResistanceSplash600 FireworkRocket FireworkStar FishingRod Flint FlintandSteel FlowerPot FlowerPotBlock Furnace FurnaceSmelting GhastSpawnEgg GhastTear Glass GlassBottle GlassPane GlisteringMelonSlice Glowstone GlowstoneDust GoldAxe GoldBoots GoldChestplate GoldHelmet GoldHoe GoldIngot GoldLeggings GoldNugget GoldOre GoldPickaxe GoldShovel GoldSword GoldenApple GoldenCarrot Grass Gravel GrayDye GrayWool GreenWool Gunpowder HarmingPotion HarmingPotionII HarmingSplash HarmingSplashII HealingPotion HealingPotionII HealingSplash HealingSplashII Hopper HopperMinecart Ice InkSack InvisibilityPotion300 InvisibilityPotion800 InvisibilitySplash215 InvisibilitySplash600 IronAxe IronBars IronBoots IronChestplate IronDoor IronDoorBlock IronHelmet IronHoe IronIngot IronLeggings IronOre IronPickaxe IronShovel IronSword ItemFrame JackOLantern Jukebox JungleLeaves JungleSapling JungleWood JungleWoodSlab JungleWoodSlabDouble JungleWoodenPlank JungleWoodenStairs Ladder LapisLazuli LapisLazuliBlock LapisLazuliOre Lava LavaBucket LavaNoSpread Leather LeatherBoots LeatherChestplate LeatherHelmet LeatherLeggings Lever LightBlueDye LightBlueWool LightGrayDye LightGrayWool LilyPad LimeDye LimeWool LockedChest MagentaDye MagentaWool MagmaCream MagmaCubeSpawnEgg Map MelonBlock MelonSeeds MelonSlice MelonVine MilkBucket Minecart MobSpawner MooshroomSpawnEgg MossStone MossyCobblestoneWall MossyStoneBricks MovingPiston MundanePotion MushroomStew MusicDisk11 MusicDisk13 MusicDiskBlocks MusicDiskCat MusicDiskChirp MusicDiskFar MusicDiskMall MusicDiskMellohi MusicDiskStal MusicDiskStrad MusicDiskWait MusicDiskWard Mycelium NetherBrick NetherBrickFence NetherBrickItem NetherBrickSlab NetherBrickSlabDouble NetherBrickStairs NetherQuartz NetherQuartzOre NetherStar NetherWart NetherWartSeeds Netherrack NightVisionPotion300 NightVisionPotion800 NightVisionSplash215 NightVisionSplash600 NoteBlock OaKWoodenPlank OakLeaves OakSapling OakWood OakWoodSlab OakWoodSlabDouble OakWoodenStairs Obsidian OcelotSpawnEgg OrangeDye OrangeWool Painting Paper PigSpawnEgg PillarQuartzBlock PinkDye PinkWool Piston PistonHead PoisonPotion045 PoisonPotion200 PoisonPotionII022 PoisonSplash033 PoisonSplash130 PoisonSplashII016 PoisonousPotato Portal Potato PotatoesCrop PoweredMinecart PoweredRail Pumpkin PumpkinPie PumpkinSeeds PumpkinVine PurpleDye PurpleWool QuartzBlock QuartzSlab QuartzSlabDouble QuartzStairs Rail RawBeef RawChicken RawFish RawPorkchop RedMushroom RedMushroomBlock RedWool RedstoneComparator RedstoneComparatorOn RedstoneComparatoroff RedstoneDust RedstoneLamp RedstoneLampOn RedstoneOre RedstoneOreGlowing RedstoneRepeater RedstoneRepeaterBlockOff RedstoneRepeaterBlockOn RedstoneTorch RedstoneTorchOff RedstoneWire RegenerationPotion045 RegenerationPotion200 RegenerationPotionII022 RegenerationSplash033 RegenerationSplash130 RegenerationSplashII016 Rose RoseRedDye RottenFlesh Saddle Sand Sandstone SandstoneSlab SandstoneSlabDouble SandstoneStairs Shears SheepSpawnEgg Sign SignBlock SignWallBlock SilverfishCobblestone SilverfishSpawnEgg SilverfishStone SilverfishStoneBrick SkeletonHead SkeletonHeadBlock SkeletonSpawnEgg SlimeBall SlimeSpawnEgg SlownessPotion130 SlownessPotion400 SlownessSplash107 SlownessSplash300 SmoothSandstone Snow SnowBlock Snowball SoulSand SpiderEye SpiderSpawnEgg SpiderString Sponge SpruceLeaves SpruceSapling SpruceWood SpruceWoodSlab SpruceWoodSlabDouble SpruceWoodenPlank SpruceWoodenStairs SquidSpawnEgg Steak SteveHead SteveHeadBlock Stick StickyPiston Stone StoneAxe StoneBrickSlab StoneBrickSlabDouble StoneBrickStairs StoneBricks StoneButton StoneHoe StonePickaxe StonePressurePlate StoneShovel StoneSlab StoneSlabDouble StoneSword StorageMinecart StrengthPotion300 StrengthPotion800 StrengthPotionII130 StrengthSplash215 StrengthSplash600 StrengthSplashII107 Sugar SugarCane SugarCaneBlock SwiftnessPotion300 SwiftnessPotion800 SwiftnessPotionII130 SwiftnessSplash215 SwiftnessSplash600 SwiftnessSplashII107 TNT TNTMinecart TallGrass TallGrassDeadShrub TallGrassFern ThickPotion Torch Trapdoor TrappedChest Tripwire TripwireHook VillagerSpawnEgg Vines Watch Water WaterBottle WaterBucket WaterNoSpread WeaknessPotion130 WeaknessPotion400 WeaknessSplash107 WeaknessSplash300 Web WeightedPressurePlateHeavy WeightedPressurePlateLight Wheat WheatCrop WheatSeeds WitchSpawnEgg WitherHead WitherHeadBlock WolfSpawnEgg WoodButton WoodDoorBlock WoodenAxe WoodenDoor WoodenHoe WoodenPickaxe WoodenPressurePlate WoodenShovel WoodenSlab WoodenSlabDouble WoodenSword Wool Workbench WrittenBook YellowWool ZombieHead ZombieHeadBlock ZombiePigmenSpawnEgg ZombieSpawnEgg'
	poolDictionaries: ''
	category: 'Minecraft-Pi-Base'!

!MinecraftConstants commentStamp: 'bf 4/9/2013 10:14' prior: 0!
Squeak Minecraft Constants (pool dictionary).
Authors: Lou LaBrunda <Lou@Keystone-Software.com> & Alex LaBrunda <Alex@LaBrunda.Info>

There are three ways to use MinecraftConstants.

The first is as a normal pool dictionary.  Add "MinecraftConstants" to the poolDictionaries list of your class and use away.  See MinecraftDemo>rainbow:.

The second is as instance methods for a class of your choosing, like Bert's Minecraft.  This requires some setup.  Run:

	MinecraftConstants compileInstanceGetters.

It will create instance side methods for each entry in this pool.  Then you can then send messages (same as pool entries but starting with a lowercase letter) to an instance of Minecraft.  See MinecraftPoolDemo>rainbow2: for an example.  Once you compile the instance side methods, you no longer need this MinecraftConstants class.

To compile instance methods for a class of your choosing use

	MinecraftConstants compileGetters: YourClass categoryPrefix: 'access-'.

The third is as class methods for a class of your choosing, like Bert's Minecraft.  This requires some setup.  Run:

	MinecraftConstants compileClassGetters.

It will create class side methods for each entry in this pool.  Then you can then send messages (same as pool entries but starting with a lowercase letter) to the Minecraft class.  See MinecraftPoolDemo>rainbow3: for an example.  Once you compile the class side methods, you no longer need this MinecraftConstants class.


To compile class methods for a class of your choosing use

	MinecraftConstants compileGetters: YourClass class categoryPrefix: 'access-'.
	
If for any reason things don't work as expected, try MinecraftConstants>initialize.
!

!MinecraftConstants class methodsFor: 'magic accessors' stamp: 'bf 4/9/2013 10:17'!
compileClassGetters
	"Add class methods to Minecraft that will return our values."

	self compileGetters: Minecraft class categoryPrefix: '*generated-'.
! !

!MinecraftConstants class methodsFor: 'private (magic accessor helpers)' stamp: 'KennethPullen 2/28/2014 22:05'!
compileGetterFor: anItem filedUnder: aProtocol on: aClass
	aClass compile: (
		self methodTemplate
			format: {
					"{1}" anItem withFirstCharacterDownshifted.
					"{2}" (MinecraftConstants bindingOf: anItem) value})
			classified: aProtocol
			notifying: nil! !

!MinecraftConstants class methodsFor: 'magic accessors' stamp: 'KennethPullen 2/28/2014 22:05'!
compileGetters: aClass categoryPrefix: aString
	"Add getter methods to aClass that will return our values. Prefix method categories with aString"
	"To add class side getters pass *aClass class* (e.g. Minecraft class)."

	'Compiling getter methods on ', aClass asString
		displayProgressFrom: 0
		to: self minecraftConstantsCategories size
		during: [ :bar |
			| count |
			count := 0.
			self minecraftConstantsCategories keysAndValuesDo: [:categoryName :items |
				items
					do: [ :item | self compileGetterFor: item filedUnder: aString, categoryName on: aClass ]
					displayingProgress: 'Compiling ', categoryName ].
				bar value: (count := count + 1). ]! !

!MinecraftConstants class methodsFor: 'magic accessors' stamp: 'bf 4/9/2013 10:18'!
compileInstanceGetters
	"Add instance methods to Minecraft that will return our values."

	self compileGetters: Minecraft categoryPrefix:  '*generated-'.
! !

!MinecraftConstants class methodsFor: 'initialize' stamp: 'LL 3/7/2013 16:37'!
initialize
	"Initialize the Minecraft Constants."
	| input |

	input := #(
		#Air 0
		#Stone 1
		#Grass 2
		#Dirt 3
		#Cobblestone 4
		#OaKWoodenPlank 5
		#SpruceWoodenPlank #(5 1)
		#BirchWoodenPlank #(5 2)
		#JungleWoodenPlank #(5 3)
		#Bedrock 7
		#Sand 12
		#Gravel 13
		#GoldOre 14
		#IronOre 15
		#CoalOre 16
		#OakWood 17
		#SpruceWood #(17 1)
		#BirchWood #(17 2)
		#JungleWood #(17 3)
		#OakLeaves 18
		#SpruceLeaves #(18 1)
		#BirchLeaves #(18 2)
		#JungleLeaves #(18 3)
		#Sponge 19
		#Glass 20
		#LapisLazuliOre 21
		#LapisLazuliBlock 22
		#Dispenser 23
		#Sandstone 24
		#ChiseledSandstone #(24 1)
		#SmoothSandstone #(24 2)
		#NoteBlock 25
		#BedBlock 26
		#StickyPiston 29
		#Piston 33
		#PistonHead 34
		#Wool 35
		#OrangeWool #(35 1)
		#MagentaWool #(35 2)
		#LightBlueWool #(35 3)
		#YellowWool #(35 4)
		#LimeWool #(35 5)
		#PinkWool #(35 6)
		#GrayWool #(35 7)
		#LightGrayWool #(35 8)
		#CyanWool #(35 9)
		#PurpleWool #(35 10)
		#BlueWool #(35 11)
		#BrownWool #(35 12)
		#GreenWool #(35 13)
		#RedWool #(35 14)
		#BlackWool #(35 15)
		#MovingPiston 36
		#BlockofGold 41
		#BlockofIron 42
		#StoneSlabDouble 43
		#SandstoneSlabDouble #(43 1)
		#WoodenSlabDouble #(43 2)
		#CobblestoneSlabDouble #(43 3)
		#BrickSlabDouble #(43 4)
		#StoneBrickSlabDouble #(43 5)
		#NetherBrickSlabDouble #(43 6)
		#QuartzSlabDouble #(43 7)
		#StoneSlab 44
		#SandstoneSlab #(44 1)
		#WoodenSlab #(44 2)
		#CobblestoneSlab #(44 3)
		#BrickSlab #(44 4)
		#StoneBrickSlab #(44 5)
		#NetherBrickSlab #(44 6)
		#QuartzSlab #(44 7)
		#Brick 45
		#TNT 46
		#Bookcase 47
		#MossStone 48
		#Obsidian 49
		#OakWoodenStairs 53
		#Chest 54
		#DiamondOre 56
		#BlockofDiamond 57
		#Workbench 58
		#Furnace 61
		#FurnaceSmelting 62
		#CobblestoneStairs 67
		#RedstoneOre 73
		#RedstoneOreGlowing 74
		#Ice 79
		#SnowBlock 80
		#Cactus 81
		#ClayBlock 82
		#Jukebox 84
		#Pumpkin 86
		#JackOLantern 91
		#CakeBlock 92
		#SilverfishStone 97
		#SilverfishCobblestone #(97 1)
		#SilverfishStoneBrick #(97 2)
		#StoneBricks 98
		#MossyStoneBricks #(98 1)
		#CrackedStoneBricks #(98 2)
		#ChiseledStoneBrick #(98 3)
		#BrownMushroomBlock 99
		#RedMushroomBlock 100
		#MelonBlock 103
		#BrickStairs 108
		#StoneBrickStairs 109
		#Mycelium 110
		#EnchantmentTable 116
		#CauldronBlock 118
		#RedstoneLamp 123
		#RedstoneLampOn 124
		#OakWoodSlabDouble 125
		#SpruceWoodSlabDouble #(125 1)
		#BirchWoodSlabDouble #(125 2)
		#JungleWoodSlabDouble #(125 3)
		#OakWoodSlab 126
		#SpruceWoodSlab #(126 1)
		#BirchWoodSlab #(126 2)
		#JungleWoodSlab #(126 3)
		#SandstoneStairs 128
		#EmeraldOre 129
		#EnderChest 130
		#BlockofEmerald 133
		#SpruceWoodenStairs 134
		#BirchWoodenStairs 135
		#JungleWoodenStairs 136
		#CommandBlock 137
		#Beacon 138
		#Anvil 145
		#BlockofRedstone 152
		#NetherQuartzOre 153
		#Hopper 154
		#QuartzBlock 155
		#ChiseledQuartzBlock #(155 1)
		#PillarQuartzBlock #(155 2)
		#QuartzStairs 156
		#Dropper 158
		#Cake 354
		#Bed 355
		#Netherrack 87
		#SoulSand 88
		#Glowstone 89
		#NetherBrick 112
		#NetherBrickFence 113
		#NetherBrickStairs 114
		#Sponge 19
		#LockedChest 95
		#OakSapling 6
		#SpruceSapling #(6 1)
		#BirchSapling #(6 2)
		#JungleSapling #(6 3)
		#PoweredRail 27
		#DetectorRail 28
		#Dandelion 37
		#Rose 38
		#BrownMushroom 39
		#RedMushroom 40
		#Torch 50
		#Fire 51
		#RedstoneWire 55
		#WheatCrop 59
		#Farmland 60
		#SignBlock 63
		#WoodDoorBlock 64
		#Ladder 65
		#Rail 66
		#SignWallBlock 68
		#Lever 69
		#StonePressurePlate 70
		#IronDoorBlock 71
		#WoodenPressurePlate 72
		#RedstoneTorchOff 75
		#RedstoneTorch 76
		#StoneButton 77
		#SugarCaneBlock 83
		#Fence 85
		#Portal 90
		#RedstoneRepeaterBlockOff 93
		#RedstoneRepeaterBlockOn 94
		#Trapdoor 96
		#IronBars 101
		#GlassPane 102
		#PumpkinVine 104
		#MelonVine 105
		#Vines 106
		#FenceGate 107
		#LilyPad 111
		#NetherWart 115
		#BrewingStandBlock 117
		#TripwireHook 131
		#Tripwire 132
		#CobblestoneWall 139
		#MossyCobblestoneWall #(139 1)
		#FlowerPotBlock 140
		#CarrotCrop 141
		#PotatoesCrop 142
		#WoodButton 143
		#WeightedPressurePlateLight 147
		#WeightedPressurePlateHeavy 148
		#RedstoneComparatoroff 149
		#RedstoneComparatorOn 150
		#DaylightSensor 151
		#ActivatorRail 157
		#Dropper 158
		#WheatSeeds 295
		#Painting 321
		#Sign 323
		#WoodenDoor 324
		#IronDoor 330
		#RedstoneDust 331
		#SugarCane 338
		#RedstoneRepeater 356
		#PumpkinSeeds 361
		#MelonSeeds 362
		#NetherWartSeeds 372
		#ItemFrame 389
		#FlowerPot 390
		#Water 8
		#WaterNoSpread 9
		#Lava 10
		#LavaNoSpread 11
		#Web 30
		#TallGrassDeadShrub 31
		#TallGrass #(31 1)
		#TallGrassFern #(31 2)
		#DeadShrub 32
		#MobSpawner 52
		#Snow 78
		#EndPortal 119
		#EndPortalFrame 120
		#EndStone 121
		#DragonEgg 122
		#CocaPlant 127
		#TrappedChest 146
		#SkeletonHeadBlock 144
		#WitherHeadBlock #(144 1)
		#ZombieHeadBlock #(144 2)
		#SteveHeadBlock #(144 3)
		#CreeperHeadBlock #(144 4)
		#SkeletonHead 397
		#WitherHead #(397 1)
		#ZombieHead #(397 2)
		#SteveHead #(397 3)
		#CreeperHead #(397 4)
		#IronShovel 256
		#IronPickaxe 257
		#IronAxe 258
		#FlintandSteel 259
		#WoodenShovel 269
		#WoodenPickaxe 270
		#WoodenAxe 271
		#StoneShovel 273
		#StonePickaxe 274
		#StoneAxe 275
		#DiamondShovel 277
		#DiamondPickaxe 278
		#DiamondAxe 279
		#GoldShovel 284
		#GoldPickaxe 285
		#GoldAxe 286
		#WoodenHoe 290
		#StoneHoe 291
		#IronHoe 292
		#DiamondHoe 293
		#GoldHoe 294
		#Bucket 325
		#WaterBucket 326
		#LavaBucket 327
		#Minecart 328
		#Saddle 329
		#Boat 333
		#MilkBucket 335
		#StorageMinecart 342
		#PoweredMinecart 343
		#Compass 345
		#FishingRod 346
		#Watch 347
		#Map 358
		#Shears 359
		#BrewingStand 379
		#Cauldron 380
		#BottleofEnchanting 384
		#FireCharge 385
		#BookandQuill 386
		#WrittenBook 387
		#Emerald 388
		#EmptyMap 395
		#CarrotonaStick 398
		#FireworkRocket 401
		#FireworkStar 402
		#EnchantedBook 403
		#RedstoneComparator 404
		#NetherBrickItem 405
		#NetherQuartz 406
		#TNTMinecart 407
		#HopperMinecart 408
		#Apple 260
		#MushroomStew 282
		#Bread 297
		#RawPorkchop 319
		#CookedPorkchop 320
		#GoldenApple 322
		#EnchantedGoldenApple #(322 1)
		#RawFish 349
		#CookedFish 350
		#Cookie 357
		#MelonSlice 360
		#RawBeef 363
		#Steak 364
		#RawChicken 365
		#CookedChicken 366
		#GlisteringMelonSlice 382
		#Carrot 391
		#Potato 392
		#BakedPotato 393
		#PoisonousPotato 394
		#GoldenCarrot 396
		#PumpkinPie 400
		#Bow 261
		#Arrow 262
		#IronSword 267
		#WoodenSword 268
		#StoneSword 272
		#DiamondSword 276
		#GoldSword 283
		#Snowball 332
		#Coal 263
		#Charcoal #(263 1)
		#DiamondGem 264
		#IronIngot 265
		#GoldIngot 266
		#Stick 280
		#Bowl 281
		#Wheat 296
		#Flint 318
		#ClayBrick 336
		#Clay 337
		#Paper 339
		#Book 340
		#GlowstoneDust 348
		#Sugar 353
		#GlassBottle 374
		#FermentedSpiderEye 376
		#BlazePowder 377
		#EyeofEnder 381
		#SpiderString 287
		#Feather 288
		#Gunpowder 289
		#Leather 334
		#SlimeBall 341
		#Egg 344
		#Bone 352
		#RottenFlesh 367
		#EnderPearl 368
		#BlazeRod 369
		#GhastTear 370
		#GoldNugget 371
		#SpiderEye 375
		#MagmaCream 378
		#NetherStar 399
		#LeatherHelmet 298
		#LeatherChestplate 299
		#LeatherLeggings 300
		#LeatherBoots 301
		#ChainmailHelmet 302
		#ChainmailChestplate 303
		#ChainmailLeggings 304
		#ChainmailBoots 305
		#IronHelmet 306
		#IronChestplate 307
		#IronLeggings 308
		#IronBoots 309
		#DiamondHelmet 310
		#DiamondChestplate 311
		#DiamondLeggings 312
		#DiamondBoots 313
		#GoldHelmet 314
		#GoldChestplate 315
		#GoldLeggings 316
		#GoldBoots 317
		#InkSack 351
		#RoseRedDye #(351 1)
		#CactusGreenDye #(351 2)
		#CocaBean #(351 3)
		#LapisLazuli #(351 4)
		#PurpleDye #(351 5)
		#CyanDye #(351 6)
		#LightGrayDye #(351 7)
		#GrayDye #(351 8)
		#PinkDye #(351 9)
		#LimeDye #(351 10)
		#DandelionYellowDye #(351 11)
		#LightBlueDye #(351 12)
		#MagentaDye #(351 13)
		#OrangeDye #(351 14)
		#BoneMeal #(351 15)
		#WaterBottle 373
		#AwkwardPotion #(373 16)
		#ThickPotion #(373 32)
		#MundanePotion #(373 64)
		#RegenerationPotion045 #(373 8193)
		#SwiftnessPotion300 #(373 8194)
		#FireResistancePotion300 #(373 8195)
		#PoisonPotion045 #(373 8196)
		#HealingPotion #(373 8197)
		#NightVisionPotion300 #(373 8198)
		#WeaknessPotion130 #(373 8200)
		#StrengthPotion300 #(373 8201)
		#SlownessPotion130 #(373 8202)
		#HarmingPotion #(373 8204)
		#InvisibilityPotion300 #(373 8206)
		#RegenerationPotionII022 #(373 8225)
		#SwiftnessPotionII130 #(373 8226)
		#PoisonPotionII022 #(373 8228)
		#HealingPotionII #(373 8229)
		#StrengthPotionII130 #(373 8233)
		#HarmingPotionII #(373 8236)
		#RegenerationPotion200 #(373 8257)
		#SwiftnessPotion800 #(373 8258)
		#FireResistancePotion800 #(373 8259)
		#PoisonPotion200 #(373 8260)
		#NightVisionPotion800 #(373 8262)
		#WeaknessPotion400 #(373 8264)
		#StrengthPotion800 #(373 8265)
		#SlownessPotion400 #(373 8266)
		#InvisibilityPotion800 #(373 8270)
		#RegenerationSplash033 #(373 16385)
		#SwiftnessSplash215 #(373 16386)
		#FireResistanceSplash215 #(373 16387)
		#PoisonSplash033 #(373 16388)
		#HealingSplash #(373 16389)
		#NightVisionSplash215 #(373 16390)
		#WeaknessSplash107 #(373 16392)
		#StrengthSplash215 #(373 16393)
		#SlownessSplash107 #(373 16394)
		#HarmingSplash #(373 16396)
		#InvisibilitySplash215 #(373 16398)
		#RegenerationSplashII016 #(373 16417)
		#SwiftnessSplashII107 #(373 16418)
		#PoisonSplashII016 #(373 16420)
		#HealingSplashII #(373 16421)
		#StrengthSplashII107 #(373 16425)
		#HarmingSplashII #(373 16428)
		#RegenerationSplash130 #(373 16449)
		#SwiftnessSplash600 #(373 16450)
		#FireResistanceSplash600 #(373 16451)
		#PoisonSplash130 #(373 16452)
		#NightVisionSplash600 #(373 16454)
		#WeaknessSplash300 #(373 16456)
		#StrengthSplash600 #(373 16457)
		#SlownessSplash300 #(373 16458)
		#InvisibilitySplash600 #(373 16462)
		#CreeperSpawnEgg #(383 50)
		#SkeletonSpawnEgg #(383 51)
		#SpiderSpawnEgg #(383 52)
		#ZombieSpawnEgg #(383 54)
		#SlimeSpawnEgg #(383 55)
		#GhastSpawnEgg #(383 56)
		#ZombiePigmenSpawnEgg #(383 57)
		#EndermenSpawnEgg #(383 58)
		#CaveSpiderSpawnEgg #(383 59)
		#SilverfishSpawnEgg #(383 60)
		#BlazeSpawnEgg #(383 61)
		#MagmaCubeSpawnEgg #(383 62)
		#BatSpawnEgg #(383 65)
		#WitchSpawnEgg #(383 66)
		#PigSpawnEgg #(383 90)
		#SheepSpawnEgg #(383 91)
		#CowSpawnEgg #(383 92)
		#ChickenSpawnEgg #(383 93)
		#SquidSpawnEgg #(383 94)
		#WolfSpawnEgg #(383 95)
		#MooshroomSpawnEgg #(383 96)
		#OcelotSpawnEgg #(383 98)
		#VillagerSpawnEgg #(383 120)
		#MusicDisk13 2256
		#MusicDiskCat 2257
		#MusicDiskBlocks 2258
		#MusicDiskChirp 2259
		#MusicDiskFar 2260
		#MusicDiskMall 2261
		#MusicDiskMellohi 2262
		#MusicDiskStal 2263
		#MusicDiskStrad 2264
		#MusicDiskWard 2265
		#MusicDisk11 2266
		#MusicDiskWait 2267
	).

	input pairsDo: [:k :v |
		MinecraftConstants classPool at: k put: v
	].
! !

!MinecraftConstants class methodsFor: 'private (magic accessor helpers)' stamp: 'KennethPullen 2/28/2014 21:32'!
methodTemplate
^ '{1}
	^{2}'! !

!MinecraftConstants class methodsFor: 'magic accessors' stamp: 'LL 3/7/2013 16:38'!
minecraftConstantsCategories
	"Answer the Minecraft Constants Categories dictionary."
	| categories input |

	categories := Dictionary new.

	input := #(
		#Air
		#Stone
		#Grass
		#Dirt
		#Cobblestone
		#OaKWoodenPlank
		#SpruceWoodenPlank
		#BirchWoodenPlank
		#JungleWoodenPlank
		#Bedrock
		#Sand
		#Gravel
		#GoldOre
		#IronOre
		#CoalOre
		#OakWood
		#SpruceWood
		#BirchWood
		#JungleWood
		#OakLeaves
		#SpruceLeaves
		#BirchLeaves
		#JungleLeaves
		#Sponge
		#Glass
		#LapisLazuliOre
		#LapisLazuliBlock
		#Dispenser
		#Sandstone
		#ChiseledSandstone
		#SmoothSandstone
		#NoteBlock
		#BedBlock
		#StickyPiston
		#Piston
		#PistonHead
		#Wool
		#OrangeWool
		#MagentaWool
		#LightBlueWool
		#YellowWool
		#LimeWool
		#PinkWool
		#GrayWool
		#LightGrayWool
		#CyanWool
		#PurpleWool
		#BlueWool
		#BrownWool
		#GreenWool
		#RedWool
		#BlackWool
		#MovingPiston
		#BlockofGold
		#BlockofIron
		#StoneSlabDouble
		#SandstoneSlabDouble
		#WoodenSlabDouble
		#CobblestoneSlabDouble
		#BrickSlabDouble
		#StoneBrickSlabDouble
		#NetherBrickSlabDouble
		#QuartzSlabDouble
		#StoneSlab
		#SandstoneSlab
		#WoodenSlab
		#CobblestoneSlab
		#BrickSlab
		#StoneBrickSlab
		#NetherBrickSlab
		#QuartzSlab
		#Brick
		#TNT
		#Bookcase
		#MossStone
		#Obsidian
		#OakWoodenStairs
		#Chest
		#DiamondOre
		#BlockofDiamond
		#Workbench
		#Furnace
		#FurnaceSmelting
		#CobblestoneStairs
		#RedstoneOre
		#RedstoneOreGlowing
		#Ice
		#SnowBlock
		#Cactus
		#ClayBlock
		#Jukebox
		#Pumpkin
		#JackOLantern
		#CakeBlock
		#SilverfishStone
		#SilverfishCobblestone
		#SilverfishStoneBrick
		#StoneBricks
		#MossyStoneBricks
		#CrackedStoneBricks
		#ChiseledStoneBrick
		#BrownMushroomBlock
		#RedMushroomBlock
		#MelonBlock
		#BrickStairs
		#StoneBrickStairs
		#Mycelium
		#EnchantmentTable
		#CauldronBlock
		#RedstoneLamp
		#RedstoneLampOn
		#OakWoodSlabDouble
		#SpruceWoodSlabDouble
		#BirchWoodSlabDouble
		#JungleWoodSlabDouble
		#OakWoodSlab
		#SpruceWoodSlab
		#BirchWoodSlab
		#JungleWoodSlab
		#SandstoneStairs
		#EmeraldOre
		#EnderChest
		#BlockofEmerald
		#SpruceWoodenStairs
		#BirchWoodenStairs
		#JungleWoodenStairs
		#CommandBlock
		#Beacon
		#Anvil
		#BlockofRedstone
		#NetherQuartzOre
		#Hopper
		#QuartzBlock
		#ChiseledQuartzBlock
		#PillarQuartzBlock
		#QuartzStairs
		#Dropper
		#Cake
		#Bed
	).
	categories at: #Blocks put: input.

	input := #(
		#Netherrack
		#SoulSand
		#Glowstone
		#NetherBrick
		#NetherBrickFence
		#NetherBrickStairs
	).
	categories at: #NetherOnlyBlocks put: input.

	input := #(
		#Sponge
		#LockedChest
	).
	categories at: #CheatOnly put: input.

	input := #(
		#OakSapling
		#SpruceSapling
		#BirchSapling
		#JungleSapling
		#PoweredRail
		#DetectorRail
		#Dandelion
		#Rose
		#BrownMushroom
		#RedMushroom
		#Torch
		#Fire
		#RedstoneWire
		#WheatCrop
		#Farmland
		#SignBlock
		#WoodDoorBlock
		#Ladder
		#Rail
		#SignWallBlock
		#Lever
		#StonePressurePlate
		#IronDoorBlock
		#WoodenPressurePlate
		#RedstoneTorchOff
		#RedstoneTorch
		#StoneButton
		#SugarCaneBlock
		#Fence
		#Portal
		#RedstoneRepeaterBlockOff
		#RedstoneRepeaterBlockOn
		#Trapdoor
		#IronBars
		#GlassPane
		#PumpkinVine
		#MelonVine
		#Vines
		#FenceGate
		#LilyPad
		#NetherWart
		#BrewingStandBlock
		#TripwireHook
		#Tripwire
		#CobblestoneWall
		#MossyCobblestoneWall
		#FlowerPotBlock
		#CarrotCrop
		#PotatoesCrop
		#WoodButton
		#WeightedPressurePlateLight
		#WeightedPressurePlateHeavy
		#RedstoneComparatoroff
		#RedstoneComparatorOn
		#DaylightSensor
		#ActivatorRail
		#Dropper
		#WheatSeeds
		#Painting
		#Sign
		#WoodenDoor
		#IronDoor
		#RedstoneDust
		#SugarCane
		#RedstoneRepeater
		#PumpkinSeeds
		#MelonSeeds
		#NetherWartSeeds
		#ItemFrame
		#FlowerPot
	).
	categories at: #PlaceableItems put: input.

	input := #(
		#Water
		#WaterNoSpread
		#Lava
		#LavaNoSpread
	).
	categories at: #Liquids put: input.

	input := #(
		#Web
		#TallGrassDeadShrub
		#TallGrass
		#TallGrassFern
		#DeadShrub
		#MobSpawner
		#Snow
		#EndPortal
		#EndPortalFrame
		#EndStone
		#DragonEgg
		#CocaPlant
		#TrappedChest
	).
	categories at: #WorldGen put: input.

	input := #(
		#SkeletonHeadBlock
		#WitherHeadBlock
		#ZombieHeadBlock
		#SteveHeadBlock
		#CreeperHeadBlock
		#SkeletonHead
		#WitherHead
		#ZombieHead
		#SteveHead
		#CreeperHead
	).
	categories at: #Heads put: input.

	input := #(
		#IronShovel
		#IronPickaxe
		#IronAxe
		#FlintandSteel
		#WoodenShovel
		#WoodenPickaxe
		#WoodenAxe
		#StoneShovel
		#StonePickaxe
		#StoneAxe
		#DiamondShovel
		#DiamondPickaxe
		#DiamondAxe
		#GoldShovel
		#GoldPickaxe
		#GoldAxe
		#WoodenHoe
		#StoneHoe
		#IronHoe
		#DiamondHoe
		#GoldHoe
		#Bucket
		#WaterBucket
		#LavaBucket
		#Minecart
		#Saddle
		#Boat
		#MilkBucket
		#StorageMinecart
		#PoweredMinecart
		#Compass
		#FishingRod
		#Watch
		#Map
		#Shears
		#BrewingStand
		#Cauldron
		#BottleofEnchanting
		#FireCharge
		#BookandQuill
		#WrittenBook
		#Emerald
		#EmptyMap
		#CarrotonaStick
		#FireworkRocket
		#FireworkStar
		#EnchantedBook
		#RedstoneComparator
		#NetherBrickItem
		#NetherQuartz
		#TNTMinecart
		#HopperMinecart
	).
	categories at: #Tools put: input.

	input := #(
		#Apple
		#MushroomStew
		#Bread
		#RawPorkchop
		#CookedPorkchop
		#GoldenApple
		#EnchantedGoldenApple
		#RawFish
		#CookedFish
		#Cookie
		#MelonSlice
		#RawBeef
		#Steak
		#RawChicken
		#CookedChicken
		#GlisteringMelonSlice
		#Carrot
		#Potato
		#BakedPotato
		#PoisonousPotato
		#GoldenCarrot
		#PumpkinPie
	).
	categories at: #Food put: input.

	input := #(
		#Bow
		#Arrow
		#IronSword
		#WoodenSword
		#StoneSword
		#DiamondSword
		#GoldSword
		#Snowball
	).
	categories at: #Weapons put: input.

	input := #(
		#Coal
		#Charcoal
		#DiamondGem
		#IronIngot
		#GoldIngot
		#Stick
		#Bowl
		#Wheat
		#Flint
		#ClayBrick
		#Clay
		#Paper
		#Book
		#GlowstoneDust
		#Sugar
		#GlassBottle
		#FermentedSpiderEye
		#BlazePowder
		#EyeofEnder
	).
	categories at: #ItemsOnlyUsedInCrafting put: input.

	input := #(
		#SpiderString
		#Feather
		#Gunpowder
		#Leather
		#SlimeBall
		#Egg
		#Bone
		#RottenFlesh
		#EnderPearl
		#BlazeRod
		#GhastTear
		#GoldNugget
		#SpiderEye
		#MagmaCream
		#NetherStar
	).
	categories at: #MobDrops put: input.

	input := #(
		#LeatherHelmet
		#LeatherChestplate
		#LeatherLeggings
		#LeatherBoots
		#ChainmailHelmet
		#ChainmailChestplate
		#ChainmailLeggings
		#ChainmailBoots
		#IronHelmet
		#IronChestplate
		#IronLeggings
		#IronBoots
		#DiamondHelmet
		#DiamondChestplate
		#DiamondLeggings
		#DiamondBoots
		#GoldHelmet
		#GoldChestplate
		#GoldLeggings
		#GoldBoots
	).
	categories at: #Armor put: input.

	input := #(
		#InkSack
		#RoseRedDye
		#CactusGreenDye
		#CocaBean
		#LapisLazuli
		#PurpleDye
		#CyanDye
		#LightGrayDye
		#GrayDye
		#PinkDye
		#LimeDye
		#DandelionYellowDye
		#LightBlueDye
		#MagentaDye
		#OrangeDye
		#BoneMeal
	).
	categories at: #Dyes put: input.

	input := #(
		#WaterBottle
		#AwkwardPotion
		#ThickPotion
		#MundanePotion
		#RegenerationPotion045
		#SwiftnessPotion300
		#FireResistancePotion300
		#PoisonPotion045
		#HealingPotion
		#NightVisionPotion300
		#WeaknessPotion130
		#StrengthPotion300
		#SlownessPotion130
		#HarmingPotion
		#InvisibilityPotion300
		#RegenerationPotionII022
		#SwiftnessPotionII130
		#PoisonPotionII022
		#HealingPotionII
		#StrengthPotionII130
		#HarmingPotionII
		#RegenerationPotion200
		#SwiftnessPotion800
		#FireResistancePotion800
		#PoisonPotion200
		#NightVisionPotion800
		#WeaknessPotion400
		#StrengthPotion800
		#SlownessPotion400
		#InvisibilityPotion800
		#RegenerationSplash033
		#SwiftnessSplash215
		#FireResistanceSplash215
		#PoisonSplash033
		#HealingSplash
		#NightVisionSplash215
		#WeaknessSplash107
		#StrengthSplash215
		#SlownessSplash107
		#HarmingSplash
		#InvisibilitySplash215
		#RegenerationSplashII016
		#SwiftnessSplashII107
		#PoisonSplashII016
		#HealingSplashII
		#StrengthSplashII107
		#HarmingSplashII
		#RegenerationSplash130
		#SwiftnessSplash600
		#FireResistanceSplash600
		#PoisonSplash130
		#NightVisionSplash600
		#WeaknessSplash300
		#StrengthSplash600
		#SlownessSplash300
		#InvisibilitySplash600
	).
	categories at: #Potions put: input.

	input := #(
		#CreeperSpawnEgg
		#SkeletonSpawnEgg
		#SpiderSpawnEgg
		#ZombieSpawnEgg
		#SlimeSpawnEgg
		#GhastSpawnEgg
		#ZombiePigmenSpawnEgg
		#EndermenSpawnEgg
		#CaveSpiderSpawnEgg
		#SilverfishSpawnEgg
		#BlazeSpawnEgg
		#MagmaCubeSpawnEgg
		#BatSpawnEgg
		#WitchSpawnEgg
		#PigSpawnEgg
		#SheepSpawnEgg
		#CowSpawnEgg
		#ChickenSpawnEgg
		#SquidSpawnEgg
		#WolfSpawnEgg
		#MooshroomSpawnEgg
		#OcelotSpawnEgg
		#VillagerSpawnEgg
	).
	categories at: #SpawnEggs put: input.

	input := #(
		#MusicDisk13
		#MusicDiskCat
		#MusicDiskBlocks
		#MusicDiskChirp
		#MusicDiskFar
		#MusicDiskMall
		#MusicDiskMellohi
		#MusicDiskStal
		#MusicDiskStrad
		#MusicDiskWard
		#MusicDisk11
		#MusicDiskWait
	).
	categories at: #MusicDisks put: input.

	^categories.
! !
MinecraftConstants initialize!
